(ns tservice.plugins.quartet-rnaseq-report.exp2qcdt
  "A wrapper for exp2qcdt tool."
  (:require [tservice.api.config :refer [add-env-to-path]]
            [tservice.lib.files :refer [get-plugin-jar-env-dir]]
            [tservice.lib.fs :as fs-lib]
            [clojure.java.shell :as shell :refer [sh]]))

(defn call-exp2qcdt!
  "Call exp2qcdt bash script.
   exp-file: FPKM file , each row is the expression values of a gene and each column is a library.
   cnt-file: Count file, each row is the expression values of a gene and each column is a library.
   meta-file: Need to contain three columns: library, group, and sample and library names must be matched with the column names in the `exp-file`.
   result-dir: A directory for result files.
  "
  [exp-file cnt-file meta-file result-dir]
  (shell/with-sh-env {:PATH   (add-env-to-path "quartet-rnaseq-report")
                      :R_PROFILE_USER (fs-lib/join-paths (get-plugin-jar-env-dir "quartet-rnaseq-report") "Rprofile")
                      :LC_ALL "en_US.utf-8"
                      :LANG   "en_US.utf-8"}
    (let [command ["bash" "-c"
                   (format "exp2qcdt.sh -e %s -c %s -m %s -o %s" exp-file cnt-file meta-file result-dir)]
          result  (apply sh command)
          status (if (= (:exit result) 0) "Success" "Error")
          msg (str (:out result) "\n" (:err result))]
      {:status status
       :msg msg})))

